@@ -135,16 +135,18 @@ class ParaDRAM:
 
     Here is a Python script main.py for a parallel ParaDRAM simulation:
 
-        from paramonte import ParaDRAM
-        pmpd = ParaDRAM()
-        def getLogFunc(Point): 
-            # return the natural logarithm of the ndim-dimensional 
-            # non-normalized Standard Gaussian density function
-            return -sum(Point**2)
-        pmpd.runSampler ( ndim = 1
-                        , getLogFunc = getLogFunc
-                        , mpiEnabled = True
-                        )
+##################################
+from paramonte import ParaDRAM
+pmpd = ParaDRAM()
+def getLogFunc(Point): 
+    # return the natural logarithm of the ndim-dimensional 
+    # non-normalized Standard Gaussian density function
+    return -sum(Point**2)
+pmpd.runSampler ( ndim = 1
+                , getLogFunc = getLogFunc
+                , mpiEnabled = True
+                )
+##################################
 
     where, 
     
@@ -189,11 +191,13 @@ class ParaDRAM:
     The best way to learn about individual ParaDRAM simulation attributes
     is to a run a minimal serial simulation with the following Python script, 
 
-        from paramonte import ParaDRAM
-        pmpd = ParaDRAM()
-        pmpd.outputFileName = "./test"
-        def getLogFunc(Point): return -sum(Point**2)
-        pmpd.runSampler( ndim = 1, getLogFunc = getLogFunc )
+##################################
+from paramonte import ParaDRAM
+pmpd = ParaDRAM()
+pmpd.outputFileName = "./test"
+def getLogFunc(Point): return -sum(Point**2)
+pmpd.runSampler( ndim = 1, getLogFunc = getLogFunc )
+##################################
 
     Running this code will generate a set of simulation output files (in the current 
     working directory of Python) that begin with the prefix "test_process_1". Among 
@@ -937,6 +941,19 @@ class ParaDRAM:
                             , marginBot = 1
                             )
 
+        if self._mpiDisabled:
+            _pm.note( msg   = "To read the generated output files sample or chain files, try the following:\n\n"
+                            + "    pmpd.readSample()      # to read the final i.i.d. sample from the output sample file. \n"
+                            + "    pmpd.readChain()       # to read the uniquely-accepted points from the output chain file. \n"
+                            + "    pmpd.readMarkovChain() # to the full Markov Chain. Not recommended for extremely-large chains.\n\n"
+                            + "Replace 'pmpd' with the name you are using for your ParaDRAM object.\n"
+                            + "For more information and examples on the usage, visit:\n\n"
+                            + "    https://www.cdslab.org/paramonte/"
+                    , methodName = _pm.names.paradram
+                    , marginTop = 1
+                    , marginBot = 1
+                    )
+
         return None
 
     ################################################################################################################################
@@ -947,7 +964,7 @@ class ParaDRAM:
                     , file          : _tp.Optional[str] = None
                     , delimiter     : _tp.Optional[str] = None
                     , parseContents : _tp.Optional[bool] = True
-                    , returnEnabled : _tp.Optional[bool] = False
+                    , renabled      : _tp.Optional[bool] = False
                     ) -> _tp.List[_ParaDRAMChain] :
         """
         Return a list of the contents of a set of ParaDRAM output 
@@ -984,7 +1001,7 @@ class ParaDRAM:
                 If set to True, the contents of the file will be parsed and 
                 stored in a component of the object named 'contents'. 
                 The default value is True. 
-            returnEnabled
+            renabled
                 If set to False, the contents of the file(s) will be stored as a 
                 list in a (new) component of the ParaDRAM object named 'chainList'
                 and None will be the return value of the method.
@@ -1013,7 +1030,7 @@ class ParaDRAM:
                     with the same name as the column header is also created 
                     for the object which contains the data stored in that column 
                     of the chain file.
-            If returnEnabled = True, the list of objects will be returned as the
+            If renabled = True, the list of objects will be returned as the
             return value of the method. Otherwise, the list will be stored in a
             component of the ParaDRAM object named 'chainList'.
 
@@ -1091,7 +1108,7 @@ class ParaDRAM:
                                     )
             chainList.append(Chain)
 
-        if returnEnabled:
+        if renabled:
             print("\n")
             return chainList
         else:
@@ -1099,9 +1116,13 @@ class ParaDRAM:
                 self.chainList = chainList
                 _pm.note( msg   = "The processed chain file(s) are now stored as a Python list in \n"
                                 + "the new component \"chainList\" of the ParaDRAM-instance object.\n"
-                                + "For example, to access the contents of the first chain file, try:\n\n"
+                                + "For example, to access the contents of the first (or the only) chain file, try:\n\n"
                                 + "    pmpd.chainList[0].df\n\n"
-                                + "where you replace 'pmpd' with the name you are using for your ParaDRAM object."
+                                + "To access plots, try:\n\n"
+                                + "    pmpd.chainList[0].plot.<PRESS TAB TO SEE THE LIST OF PLOTS>\n\n"
+                                + "Replace 'pmpd' with the name you are using for your ParaDRAM object.\n"
+                                + "For more information and examples on the usage, visit:\n\n"
+                                + "    https://www.cdslab.org/paramonte/"
                         , methodName = _pm.names.paradram
                         , marginTop = 1
                         , marginBot = 1
@@ -1114,7 +1135,7 @@ class ParaDRAM:
                         , file          : _tp.Optional[str] = None
                         , delimiter     : _tp.Optional[str] = None
                         , parseContents : _tp.Optional[bool] = True
-                        , returnEnabled : _tp.Optional[bool] = False
+                        , renabled      : _tp.Optional[bool] = False
                         ) -> _tp.List[_ParaDRAMChain] :
         """
         Return a list of the unweighted (Markov-chain) contents of a set of 
@@ -1151,7 +1172,7 @@ class ParaDRAM:
                 If set to True, the contents of the file will be parsed and 
                 stored in a component of the object named 'contents'.
                 The default value is True.
-            returnEnabled
+            renabled
                 If set to False, the contents of the file(s) will be stored as a 
                 list in a (new) component of the ParaDRAM object named 'markovChainList'
                 and None will be the return value of the method.
@@ -1180,7 +1201,7 @@ class ParaDRAM:
                     with the same name as the column header is also created 
                     for the object which contains the data stored in that column 
                     of the chain file.
-            If returnEnabled = True, the list of objects will be returned as the
+            If renabled = True, the list of objects will be returned as the
             return value of the method. Otherwise, the list will be stored in a
             component of the ParaDRAM object named 'markovChainList'.
 
@@ -1259,7 +1280,7 @@ class ParaDRAM:
                                     )
             markovChainList.append(Chain)
 
-        if returnEnabled:
+        if renabled:
             print("\n")
             return markovChainList
         else:
@@ -1267,9 +1288,13 @@ class ParaDRAM:
                 self.markovChainList = markovChainList
                 _pm.note( msg   = "The processed Markov chain file(s) are now stored as a Python list in \n"
                                 + "the new component \"markovChainList\" of the ParaDRAM-instance object.\n"
-                                + "For example, to access the contents of the first Markov chain, try:\n\n"
+                                + "For example, to access the contents of the first (or the only) Markov chain, try:\n\n"
                                 + "    pmpd.markovChainList[0].df\n\n"
-                                + "where you replace 'pmpd' with the name you are using for your ParaDRAM object."
+                                + "To access plots, try:\n\n"
+                                + "    pmpd.markovChainList[0].plot.<PRESS TAB TO SEE THE LIST OF PLOTS>\n\n"
+                                + "Replace 'pmpd' with the name you are using for your ParaDRAM object.\n"
+                                + "For more information and examples on the usage, visit:\n\n"
+                                + "    https://www.cdslab.org/paramonte/"
                         , methodName = _pm.names.paradram
                         , marginTop = 1
                         , marginBot = 1
@@ -1281,7 +1306,7 @@ class ParaDRAM:
                     , file          : _tp.Optional[str] = None
                     , delimiter     : _tp.Optional[str] = None
                     , parseContents : _tp.Optional[bool] = True
-                    , returnEnabled : _tp.Optional[bool] = False
+                    , renabled      : _tp.Optional[bool] = False
                     ) -> _tp.List[_ParaDRAMChain] :
         """
         Return a list of the contents of a set of ParaDRAM output 
@@ -1318,7 +1343,7 @@ class ParaDRAM:
                 If set to True, the contents of the file will be parsed and 
                 stored in a component of the object named 'contents'.
                 The default value is True.
-            returnEnabled
+            renabled
                 If set to False, the contents of the file(s) will be stored as a 
                 list in a (new) component of the ParaDRAM object named 'sampleList'
                 and None will be the return value of the method.
@@ -1345,7 +1370,7 @@ class ParaDRAM:
                     with the same name as the column header is also created 
                     for the object which contains the data stored in that column 
                     of the sample file.
-            If returnEnabled = True, the list of objects will be returned as the
+            If renabled = True, the list of objects will be returned as the
             return value of the method. Otherwise, the list will be stored in a
             component of the ParaDRAM object named 'sampleList'.
 
@@ -1419,7 +1444,7 @@ class ParaDRAM:
                                     )
             sampleList.append(Sample)
 
-        if returnEnabled:
+        if renabled:
             print("\n")
             return sampleList
         else:
@@ -1427,9 +1452,13 @@ class ParaDRAM:
                 self.sampleList = sampleList
                 _pm.note( msg   = "The processed sample file(s) are now stored as a Python list in \n"
                                 + "the new component \"sampleList\" of the ParaDRAM-instance object.\n"
-                                + "For example, to access the contents of the first sample file, try:\n\n"
+                                + "For example, to access the contents of the first (or the only) sample file, try:\n\n"
                                 + "    pmpd.sampleList[0].df\n\n"
-                                + "where you replace 'pmpd' with the name you are using for your ParaDRAM object."
+                                + "To access plots, try:\n\n"
+                                + "    pmpd.sampleList[0].plot.<PRESS TAB TO SEE THE LIST OF PLOTS>\n\n"
+                                + "Replace 'pmpd' with the name you are using for your ParaDRAM object.\n"
+                                + "For more information and examples on the usage, visit:\n\n"
+                                + "    https://www.cdslab.org/paramonte/"
                         , methodName = _pm.names.paradram
                         , marginTop = 1
                         , marginBot = 1
